package dune

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Tag.Handler

type t = unit
val init : t

Initial tag handler

val handle : t -> t -> string * t * string

Handle a tag: return the string that enables the tag, the handler while the tag is active and the string to disable the tag.